@@ -19,24 +19,25 @@ use IPC::System::Simple    qw( capture );
 use Term::Choose           qw( choose );
 use Term::ReadLine::Simple qw();
 use Text::LineFold         qw();
-use Try::Tiny              qw( try );
+use Try::Tiny              qw( try catch );
 
-use App::YTDL::Helper qw( term_size print_hash encode_fs choose_a_dir
-                          choose_a_number insert_sep write_json read_json );
+use App::YTDL::Helper qw( term_size print_hash encode_fs choose_a_dir choose_a_number
+                          insert_sep write_json read_json HIDE_CURSOR SHOW_CURSOR );
 
 
 
 sub _menus {
     my $menus = {
         main => [
-            [ 'show_help_text',  "  HELP"      ],
-            [ 'show_info',       "  INFO"      ],
-            [ 'group_directory', "- Directory" ],
-            [ 'group_file',      "- File" ],
-            [ 'group_quality',   "- Quality"   ],
-            [ 'group_download',  "- Download"  ],
-            [ 'group_history',   "- History"   ],
-            [ 'group_output',    "- Appearance"    ],
+            [ 'show_help_text',  "  HELP"       ],
+            [ 'show_info',       "  INFO"       ],
+            [ 'group_directory', "- Directory"  ],
+            [ 'group_file',      "- File"       ],
+            [ 'group_quality',   "- Quality"    ],
+            [ 'group_download',  "- Download"   ],
+            [ 'group_history',   "- History"    ],
+            [ 'group_output',    "- Appearance" ],
+            [ 'list_extractors', "  Extractors" ],
         ],
         group_download => [
             [ 'useragent',      "- UserAgent"           ],
@@ -155,6 +156,26 @@ sub set_options {
                 push @$keys, $youtube_dl if $youtube_dl_version;
                 print_hash( $path, { keys => $keys, preface => ' Close with ENTER' } );
             }
+            elsif ( $choice eq "list_extractors" ) {
+                print HIDE_CURSOR;
+                say 'Close with ENTER';
+                my @capture;
+                try {
+                    my $youtube_dl = which( 'youtube-dl' ) // 'youtube-dl';
+                    @capture = capture( $youtube_dl, '--list-extractors' );
+
+                }
+                catch {
+                    say "List extractors: $_";
+                };
+                print SHOW_CURSOR;
+                if ( @capture ) {
+                    choose(
+                        [ map { "  $_" } @capture ],
+                        { layout => 3 }
+                    );
+                }
+            }
             elsif ( $choice eq "print_pref_qual" ) {
                 my $pref = read_json( $opt->{preferred_file} );
                 if ( ! %$pref ) {
