@@ -61,7 +61,7 @@ sub linefolded_print_info {
     my $col_max = $maxcols > $opt->{max_info_width} ? $opt->{max_info_width} : $maxcols;
     my $lf = Text::LineFold->new( %{$opt->{linefold}} );
     $lf->config( 'ColMax', $col_max );
-    my $print_array;
+    my $print_array = [];
     for my $key ( @keys ) {
         next if ! length $info->{$video_id}{$key};
         $info->{$video_id}{$key} =~ s/\n+/\n/g;
@@ -74,6 +74,7 @@ sub linefolded_print_info {
             push @$print_array, $val . "\n";
         }
     }
+    return $print_array if ! @$print_array;
     # auto width:
     my $ratio = @$print_array / $maxrows;
     my $begin = 0.70;
